@@ -6,8 +6,9 @@ from enum import Enum
 import logging
 
 # Default Config Items
+TFC_SAAS_HOSTNAME = "app.terraform.io"
 TFC_SAAS_URL = "https://app.terraform.io"
-LOG_LEVEL = logging.INFO
+API_LOG_LEVEL = logging.CRITICAL
 MAX_PAGE_SIZE = 100
 
 # Common TFC API HTTP Codes
@@ -26,6 +27,7 @@ HTTP_NOT_FOUND = 404
 HTTP_CONFLICT = 409
 HTTP_PRECONDITION_FAILED = 412
 HTTP_UNPROCESSABLE_ENTITY = 422
+HTTP_API_REQUEST_RATE_LIMIT_REACHED = 429
 HTTP_INTERNAL_SERVER_ERROR = 500
 
 
@@ -36,18 +38,18 @@ class Entitlements(Enum):
     of the Terraform Cloud API.
     """
 
-    COST_ESTIMATION = "COST_ESTIMATION"
+    AGENTS = "AGENTS"
+    AUDIT_LOGGING = "AUDIT_LOGGING"
     CONFIGURATION_DESIGNER = "CONFIGURATION_DESIGNER"
+    COST_ESTIMATION = "COST_ESTIMATION"
     OPERATIONS = "OPERATIONS"
     PRIVATE_MODULE_REGISTRY = "PRIVATE_MODULE_REGISTRY"
+    PRIVATE_NETWORKING = "PRIVATE_NETWORKING"
+    SELF_SERVE_BILLING = "SELF_SERVE_BILLING"
     SENTINEL = "SENTINEL"
     STATE_STORAGE = "STATE_STORAGE"
-    TEAMS = "TEAMS"
-    VCS_INTEGRATIONS = "VCS_INTEGRATIONS"
-    USER_LIMIT = "USER_LIMIT"
-    SELF_SERVE_BILLING = "SELF_SERVE_BILLING"
-    AUDIT_LOGGING = "AUDIT_LOGGING"
-    PRIVATE_NETWORKING = "PRIVATE_NETWORKING"
     SSO = "SSO"
-    AGENTS = "AGENTS"
+    TEAMS = "TEAMS"
+    USER_LIMIT = "USER_LIMIT"
     USAGE_REPORTING = "USAGE_REPORTING"
+    VCS_INTEGRATIONS = "VCS_INTEGRATIONS"
