@@ -17,6 +17,12 @@ class TFCAccount(TFCEndpoint):
     def required_entitlements(self):
         return []
 
+    def terraform_cloud_only(self):
+        return False
+
+    def terraform_enterprise_only(self):
+        return False
+
     def show(self):
         """
         ``GET /account/details``
