@@ -8,8 +8,11 @@ import logging
 import requests
 import urllib3
 
-from ._constants import TFC_SAAS_URL, HTTP_OK, LOG_LEVEL
+from ._constants import TFC_SAAS_URL, TFC_SAAS_HOSTNAME, HTTP_OK, API_LOG_LEVEL
+from .exceptions import TFCHTTPNotFound
+
 from .account import TFCAccount
+from .admin_module_sharing import TFCAdminModuleSharing
 from .admin_orgs import TFCAdminOrgs
 from .admin_runs import TFCAdminRuns
 from .admin_settings import TFCAdminSettings
@@ -22,7 +25,9 @@ from .applies import TFCApplies
 from .audit_trails import TFCAuditTrails
 from .config_versions import TFCConfigVersions
 from .cost_estimates import TFCCostEstimates
+from .feature_sets import TFCFeatureSets
 from .ip_ranges import TFCIPRanges
+from .invoices import TFCInvoices
 from .oauth_clients import TFCOAuthClients
 from .oauth_tokens import TFCOAuthTokens
 from .orgs import TFCOrgs
@@ -41,6 +46,7 @@ from .runs import TFCRuns
 from .state_versions import TFCStateVersions
 from .state_version_outputs import TFCStateVersionOutputs
 from .ssh_keys import TFCSSHKeys
+from .subscriptions import TFCSubscriptions
 from .teams import TFCTeams
 from .team_access import TFCTeamAccess
 from .team_memberships import TFCTeamMemberships
@@ -70,6 +76,7 @@ class TFC():
     _class_for_attr_dict = {
         "org-not-required": {
             "admin_orgs": TFCAdminOrgs,
+            "admin_module_sharing": TFCAdminModuleSharing,
             "admin_runs": TFCAdminRuns,
             "admin_settings": TFCAdminSettings,
             "admin_terraform_versions": TFCAdminTerraformVersions,
@@ -86,6 +93,8 @@ class TFC():
             "agent_tokens": TFCAgentTokens,
             "config_versions": TFCConfigVersions,
             "cost_estimates": TFCCostEstimates,
+            "feature_sets": TFCFeatureSets,
+            "invoices": TFCInvoices,
             "oauth_clients": TFCOAuthClients,
             "oauth_tokens": TFCOAuthTokens,
             "org_memberships": TFCOrgMemberships,
@@ -100,9 +109,10 @@ class TFC():
             "registry_modules": TFCRegistryModules,
             "run_triggers": TFCRunTriggers,
             "runs": TFCRuns,
+            "ssh_keys": TFCSSHKeys,
             "state_versions": TFCStateVersions,
             "state_version_outputs": TFCStateVersionOutputs,
-            "ssh_keys": TFCSSHKeys,
+            "subscriptions": TFCSubscriptions,
             "teams": TFCTeams,
             "team_access": TFCTeamAccess,
             "team_memberships": TFCTeamMemberships,
@@ -115,7 +125,7 @@ class TFC():
         }
     }
 
-    def __init__(self, api_token, url=TFC_SAAS_URL, verify=True, log_level=LOG_LEVEL):
+    def __init__(self, api_token, url=TFC_SAAS_URL, verify=True, log_level=API_LOG_LEVEL):
         if api_token is None:
             raise InvalidTFCTokenException
 
@@ -130,6 +140,7 @@ class TFC():
         self._current_org = None
         self._verify = verify
 
+        self.admin_module_sharing: TFCAdminModuleSharing = None
         self.admin_orgs: TFCAdminOrgs = None
         self.admin_runs: TFCAdminRuns = None
         self.admin_settings: TFCAdminSettings = None
@@ -137,7 +148,9 @@ class TFC():
         self.admin_users: TFCAdminUsers = None
         self.admin_workspaces: TFCAdminWorkspaces = None
         self.audit_trails: TFCAuditTrails = None
+        self.invoices: TFCInvoices = None
         self.ip_ranges: TFCIPRanges = None
+        self.feature_sets: TFCFeatureSets = None
         self.orgs: TFCOrgs = None
         self.account: TFCAccount = None
         self.applies: TFCApplies = None
@@ -182,7 +195,6 @@ class TFC():
         self.set_token(api_token)
         self._initialize_endpoints()
 
-
     def _get(self, url):
         """
         Simplified HTTP GET function for usage only with this API module.
@@ -220,14 +232,12 @@ class TFC():
 
         self._logger.debug("TFC API class initialized.")
 
-
     def get_url(self):
         """
         Allows for the user to retrieve the URL being hit from the API object.
         """
         return self._instance_url
 
-
     def set_org(self, org_name):
         """
         Sets the organization to use for org specific endpoints.
@@ -253,13 +263,27 @@ class TFC():
 
         self._logger.debug("Initialized endpoints that do require an org to be set.")
 
-
     def get_org(self):
         """
         Allows for the user to retrieve the current org from the API object.
         """
         return self._current_org
 
+    def get_entitlements(self):
+        """
+        Allows for the user to retrieve the entitlements to the API for the current org.
+        """
+        entitlements = None
+
+        if self.is_terraform_cloud():
+            try:
+                entitlements = self.orgs.entitlements(self._current_org)["data"]["attributes"]
+            except TFCHTTPNotFound:
+                self._logger.debug("Entitlements API endpoint not found. No entitlements recorded.")
+        else:
+            self._logger.debug("Not Terraform Cloud, so entitlements API is not supported.")
+
+        return entitlements
 
     def set_token(self, token):
         """
@@ -279,6 +303,10 @@ class TFC():
         """
         return self._token
 
+    def is_terraform_cloud(self):
+        return TFC_SAAS_HOSTNAME in self._instance_url
+
+
     def well_known_paths(self):
         """
         Retrieve all the well known paths from the Terraform Cloud installation.
