@@ -11,12 +11,13 @@ import requests
 from .exceptions import \
     TFCHTTPBadRequest, TFCHTTPUnauthorized, TFCHTTPForbidden, TFCHTTPNotFound, \
         TFCHTTPConflict, TFCHTTPPreconditionFailed, TFCHTTPUnprocessableEntity, \
-            TFCHTTPInternalServerError, TFCHTTPUnclassified
+            TFCHTTPInternalServerError, TFCHTTPUnclassified, TFCHTTPAPIRequestRateLimit
 
 from ._constants import \
     HTTP_OK, HTTP_CREATED, HTTP_ACCEPTED, HTTP_NO_CONTENT, HTTP_BAD_REQUEST, HTTP_UNAUTHORIZED, \
         HTTP_FORBIDDEN, HTTP_NOT_FOUND, HTTP_CONFLICT, HTTP_PRECONDITION_FAILED, \
-            HTTP_UNPROCESSABLE_ENTITY, HTTP_INTERNAL_SERVER_ERROR
+            HTTP_UNPROCESSABLE_ENTITY, HTTP_API_REQUEST_RATE_LIMIT_REACHED, \
+                HTTP_INTERNAL_SERVER_ERROR
 
 
 class TFCEndpoint(ABC):
@@ -33,7 +34,7 @@ class TFCEndpoint(ABC):
             instance_url if instance_url[-1] != "/" else instance_url[:-1]
         self._api_v2_base_url = f"{self._instance_url}{well_known_paths['tfe.v2'][:-1]}"
         self._meta_base_url = f"{self._instance_url}/api/meta"
-        self._modules_v1_base_url = f"{self._instance_url}{well_known_paths['modules.v1']}"
+        self._modules_v1_base_url = f"{self._instance_url}{well_known_paths['modules.v1'][:-1]}"
         self._headers = headers
         self._org_name = org_name
         self._verify = verify
@@ -45,6 +46,20 @@ class TFCEndpoint(ABC):
         """
         return []
 
+    @abstractmethod
+    def terraform_cloud_only(self):
+        """
+        Return ``True`` if this endpoint is only for Terraform Cloud, else ``False``.
+        """
+        return False
+
+    @abstractmethod
+    def terraform_enterprise_only(self):
+        """
+        Return ``True`` if this endpoint is only for Terraform Enterprise, else ``False``.
+        """
+        return False
+
     def _delete(self, url, data=None):
         results = None
         req = requests.delete(\
@@ -60,6 +75,10 @@ class TFCEndpoint(ABC):
             err = json.loads(req.content.decode("utf-8"))
             self._logger.debug(err)
             raise TFCHTTPForbidden(err)
+        elif req.status_code == HTTP_API_REQUEST_RATE_LIMIT_REACHED:
+            err = json.loads(req.content.decode("utf-8"))
+            self._logger.debug(err)
+            raise TFCHTTPAPIRequestRateLimit(err)
         else:
             err = json.loads(req.content.decode("utf-8"))
             self._logger.debug(err)
@@ -94,6 +113,10 @@ class TFCEndpoint(ABC):
             err = json.loads(req.content.decode("utf-8"))
             self._logger.debug(err)
             raise TFCHTTPNotFound(err)
+        elif req.status_code == HTTP_API_REQUEST_RATE_LIMIT_REACHED:
+            err = json.loads(req.content.decode("utf-8"))
+            self._logger.debug(err)
+            raise TFCHTTPAPIRequestRateLimit(err)
         else:
             err = json.loads(req.content.decode("utf-8"))
             self._logger.debug(err)
@@ -121,6 +144,10 @@ class TFCEndpoint(ABC):
             err = json.loads(req.content.decode("utf-8"))
             self._logger.debug(err)
             raise TFCHTTPUnprocessableEntity(err)
+        elif req.status_code == HTTP_API_REQUEST_RATE_LIMIT_REACHED:
+            err = json.loads(req.content.decode("utf-8"))
+            self._logger.debug(err)
+            raise TFCHTTPAPIRequestRateLimit(err)
         else:
             err = json.loads(req.content.decode("utf-8"))
             self._logger.debug(err)
@@ -159,6 +186,10 @@ class TFCEndpoint(ABC):
             err = json.loads(req.content.decode("utf-8"))
             self._logger.debug(err)
             raise TFCHTTPUnprocessableEntity(err)
+        elif req.status_code == HTTP_API_REQUEST_RATE_LIMIT_REACHED:
+            err = json.loads(req.content.decode("utf-8"))
+            self._logger.debug(err)
+            raise TFCHTTPAPIRequestRateLimit(err)
         elif req.status_code == HTTP_INTERNAL_SERVER_ERROR:
             err = json.loads(req.content.decode("utf-8"))
             self._logger.debug(err)
@@ -185,6 +216,10 @@ class TFCEndpoint(ABC):
             if octet:
                 results = json.loads(req.content)
             self._logger.debug(f"PUT to {url} successful")
+        elif req.status_code == HTTP_API_REQUEST_RATE_LIMIT_REACHED:
+            err = json.loads(req.content.decode("utf-8"))
+            self._logger.debug(err)
+            raise TFCHTTPAPIRequestRateLimit(err)
         else:
             err = json.loads(req.content.decode("utf-8"))
             self._logger.debug(err)
@@ -192,10 +227,13 @@ class TFCEndpoint(ABC):
 
         return results
 
-    def _create(self, url, payload):
+    def _create(self, url, payload=None):
         """
         Implementation the common create resource pattern for the TFC API.
         """
+        if payload is None:
+            payload = {}
+
         return self._post(url, data=payload)
 
     def _destroy(self, url):
@@ -207,6 +245,10 @@ class TFCEndpoint(ABC):
         valid_status_codes = [HTTP_OK, HTTP_NO_CONTENT]
         if req.status_code in valid_status_codes:
             self._logger.debug(f"Terraform Cloud resource at URL [{url}] destroyed.")
+        elif req.status_code == HTTP_API_REQUEST_RATE_LIMIT_REACHED:
+            err = json.loads(req.content.decode("utf-8"))
+            self._logger.debug(err)
+            raise TFCHTTPAPIRequestRateLimit(err)
         else:
             err = json.loads(req.content.decode("utf-8"))
             self._logger.debug(err)
