@@ -17,6 +17,12 @@ class TFCIPRanges(TFCEndpoint):
     def required_entitlements(self):
         return []
 
+    def terraform_cloud_only(self):
+        return True
+
+    def terraform_enterprise_only(self):
+        return False
+
     def list(self):
         """
         ``GET /meta/ip-ranges``
