@@ -23,6 +23,12 @@ class TFCRegistryModules(TFCEndpoint):
     def required_entitlements(self):
         return [Entitlements.PRIVATE_MODULE_REGISTRY]
 
+    def terraform_cloud_only(self):
+        return False
+
+    def terraform_enterprise_only(self):
+        return False
+
     # Public Registry API Endpoints
     def list(self, offset=None, limit=None, provider=None, verified=None):
         """
@@ -32,6 +38,7 @@ class TFCRegistryModules(TFCEndpoint):
         `Registry Modules List API Doc Reference \
             <https://www.terraform.io/docs/registry/api.html#list-modules>`_
         """
+        # TODO: the slash here is behaving differently from TFE to TFC
         url = f"{self._modules_v1_base_url}/{self._org_name}"
         return self._list(\
             url, offset=offset, limit=limit, provider=provider, verified=verified)
@@ -43,6 +50,7 @@ class TFCRegistryModules(TFCEndpoint):
         `Registry Modules Search API Doc Reference \
             <https://www.terraform.io/docs/registry/api.html#search-modules>`_
         """
+        # TODO: the slash here is behaving differently from TFE to TFC
         url = f"{self._modules_v1_base_url}/search"
         return self._list(url, \
             query=query, offset=offset, limit=limit, provider=provider,\
@@ -132,7 +140,7 @@ class TFCRegistryModules(TFCEndpoint):
         """
         return self._post(self._modules_v2_base_url, data=payload)
 
-    def destroy(self, name, provider=None, version=None):
+    def destroy(self, module_name, provider=None, version=None):
         """
         ``POST /registry-modules/actions/delete/:organization_name/:name/:provider/:version``
         ``POST /registry-modules/actions/delete/:organization_name/:name/:provider``
@@ -141,14 +149,12 @@ class TFCRegistryModules(TFCEndpoint):
         `Registry Modules Destroy API Doc Reference \
             <https://www.terraform.io/docs/cloud/api/modules.html#delete-a-module>`_
         """
-        url = f"{self._modules_v2_base_url}/actions/delete/{self._org_name}"
+        url = f"{self._modules_v2_base_url}/actions/delete/{self._org_name}/{module_name}"
 
-        if name:
-            url += f"/{name}"
-            if provider:
-                url += f"/{provider}"
-                if version:
-                    url += f"/{version}"
+        if provider:
+            url += f"/{provider}"
+            if version:
+                url += f"/{version}"
 
         return self._post(url)
 
