@@ -18,6 +18,12 @@ class TFCRunTriggers(TFCEndpoint):
     def required_entitlements(self):
         return []
 
+    def terraform_cloud_only(self):
+        return False
+
+    def terraform_enterprise_only(self):
+        return False
+
     def create(self, workspace_id, payload):
         """
         ``POST /workspaces/:workspace_id/run-triggers``
