@@ -18,6 +18,12 @@ class TFCTeamAccess(TFCEndpoint):
     def required_entitlements(self):
         return [Entitlements.TEAMS]
 
+    def terraform_cloud_only(self):
+        return False
+
+    def terraform_enterprise_only(self):
+        return False
+
     def add_team_access(self, payload):
         """
         ``POST /team-workspaces``
