@@ -18,6 +18,12 @@ class TFCTeamMemberships(TFCEndpoint):
     def required_entitlements(self):
         return [Entitlements.TEAMS]
 
+    def terraform_cloud_only(self):
+        return False
+
+    def terraform_enterprise_only(self):
+        return False
+
     def add_user_to_team(self, team_id, payload):
         """
         ``POST /teams/:team_id/relationships/users``
