@@ -18,6 +18,12 @@ class TFCTeamTokens(TFCEndpoint):
     def required_entitlements(self):
         return [Entitlements.TEAMS]
 
+    def terraform_cloud_only(self):
+        return False
+
+    def terraform_enterprise_only(self):
+        return False
+
     def create(self, team_id, payload=None):
         """
         ``POST /teams/:team_id/authentication-token``
@@ -26,9 +32,6 @@ class TFCTeamTokens(TFCEndpoint):
             <https://www.terraform.io/docs/cloud/api/team-tokens.html#generate-a-new-team-token>`_
         """
 
-        if payload is None:
-            payload = {}
-
         url = f"{self._endpoint_base_url}/{team_id}/authentication-token"
         return self._create(url, payload=payload)
 
