@@ -17,6 +17,12 @@ class TFCUsers(TFCEndpoint):
     def required_entitlements(self):
         return []
 
+    def terraform_cloud_only(self):
+        return False
+
+    def terraform_enterprise_only(self):
+        return False
+
     def show(self, user_id):
         """
         ``GET /users/:user_id``
