@@ -17,6 +17,12 @@ class TFCWorkspaceVars(TFCEndpoint):
     def required_entitlements(self):
         return []
 
+    def terraform_cloud_only(self):
+        return False
+
+    def terraform_enterprise_only(self):
+        return False
+
     def create(self, workspace_id, payload):
         """
         ``POST /workspaces/:workspace_id/vars``
