@@ -19,6 +19,12 @@ class TFCWorkspaces(TFCEndpoint):
     def required_entitlements(self):
         return []
 
+    def terraform_cloud_only(self):
+        return False
+
+    def terraform_enterprise_only(self):
+        return False
+
     def create(self, payload):
         """
         ``POST /organizations/:organization_name/workspaces``
@@ -96,7 +102,7 @@ class TFCWorkspaces(TFCEndpoint):
         """
         current_page_number = 1
         workspaces_resp = \
-            self._list(self._org_api_v2_base_url, page=current_page_number, page_size=MAX_PAGE_SIZE)
+            self.list(page=current_page_number, page_size=MAX_PAGE_SIZE)
         total_pages = workspaces_resp["meta"]["pagination"]["total-pages"]
 
         workspaces = []
@@ -155,7 +161,6 @@ class TFCWorkspaces(TFCEndpoint):
             self._logger.error("Arguments workspace_name or workspace_id must be defined")
         return self._update(url, payload)
 
-
     def assign_ssh_key(self, workspace_id, payload):
         """
         ``PATCH /workspaces/:workspace_id/relationships/ssh-key``
