@@ -24,3 +24,6 @@ class TestTFCAuditTrails(TestTFCBaseTestCase):
 
         audit_trails = self._api.audit_trails.list()["data"]
         self.assertEqual(len(audit_trails), 0)
+
+        all_audit_trails = self._api.audit_trails.list_all()
+        self.assertEqual(len(all_audit_trails), 0)
