@@ -22,7 +22,7 @@ from ._constants import \
     TEST_ORG_NAME, TEST_USERNAME, TEST_TEAM_NAME, \
     GITHUB_TOKEN, GITHUB_SECRET, \
     SSL_VERIFY, TEST_PASSWORD, MAX_TEST_TIMEOUT, \
-    DEFAULT_VCS_WORKING_DIR, TFC_SAAS_HOSTNAME, API_LOG_LEVEL
+    DEFAULT_VCS_WORKING_DIR, API_LOG_LEVEL
 
 class TestTFCBaseTestCase(unittest.TestCase):
     """
@@ -37,7 +37,7 @@ class TestTFCBaseTestCase(unittest.TestCase):
     @classmethod
     def setUpClass(cls):
         cls._logger = logging.getLogger(cls.__class__.__name__)
-        cls._logger.setLevel(logging.INFO)
+        cls._logger.setLevel(API_LOG_LEVEL)
         cls._tfc_url = TFC_URL
 
         cls._test_api_token = TFC_TOKEN
@@ -101,9 +101,16 @@ class TestTFCBaseTestCase(unittest.TestCase):
                 "Missing required Terraform Cloud Entitlments for test", \
                     cls._unittest_name, missing_entitlements)
 
-        if TFC_SAAS_HOSTNAME in TFC_URL and "admin" in str(cls._endpoint_being_tested):
+        endpoint_to_test = getattr(cls._api, cls._endpoint_being_tested)
+
+        if cls._api.is_terraform_cloud() and endpoint_to_test.terraform_enterprise_only():
             raise unittest.SkipTest(\
-                "Skipping Admin Test since we're testing against Terraform Cloud.")
+                (f"Skipping Test (%s), since we're testing against Terraform Cloud." % cls._endpoint_being_tested))
+        elif not cls._api.is_terraform_cloud() and endpoint_to_test.terraform_cloud_only():
+            raise unittest.SkipTest(\
+                (f"Skipping Test (%s), since we're testing against Terraform Enterprise." % cls._endpoint_being_tested))
+        else:
+            cls._logger.debug("Endpoint", cls._endpoint_being_tested, " not expected.")
 
         cls._purge_organization()
 
@@ -111,7 +118,9 @@ class TestTFCBaseTestCase(unittest.TestCase):
     def tearDownClass(cls):
         # Only destroy the org if we auto generated it
         if not TEST_ORG_NAME:
+            cls._logger.debug("Destroying autogenerated org %s...", cls._test_org_name)
             cls._api.orgs.destroy(cls._test_org_name)
+            cls._logger.debug("Destroyed autogenerated org %s.", cls._test_org_name)
 
     @classmethod
     def _purge_organization(cls):
@@ -124,12 +133,9 @@ class TestTFCBaseTestCase(unittest.TestCase):
             cls._api.workspaces.destroy(workspace_id=workspace["id"])
         cls._logger.debug(f"Workspaces purged from test org ({cls._test_org_name}).")
 
-        cls._logger.debug(f"Purging test org ({cls._test_org_name}) of modules...")
-        registry_modules = cls._api.registry_modules.list()["modules"]
-        for registry_module in registry_modules:
-            cls._api.registry_modules.destroy(registry_module["name"])
-        cls._logger.debug(f"Modules purged from test org ({cls._test_org_name}).")
+        cls._purge_module_registry()
 
+        cls._logger.debug(f"Modules purged from test org ({cls._test_org_name}).")
 
         cls._logger.debug(f"Purging test org ({cls._test_org_name}) of policies...")
         policies = cls._api.policies.list_all()
@@ -174,11 +180,12 @@ class TestTFCBaseTestCase(unittest.TestCase):
                 cls._api.org_memberships.remove(membership_id)
         cls._logger.debug(f"Org member invites purged from test org ({cls._test_org_name}).")
 
-        cls._logger.debug(f"Purging test org ({cls._test_org_name}) of agent pools...")
-        agent_pools = cls._api.agents.list_pools()["data"]
-        for agent_pool in agent_pools:
-            cls._api.agents.destroy(agent_pool["id"])
-        cls._logger.debug(f"Agent pools purged from test org ({cls._test_org_name}).")
+        if cls._api.is_terraform_cloud():
+            cls._logger.debug(f"Purging test org ({cls._test_org_name}) of agent pools...")
+            agent_pools = cls._api.agents.list_pools()["data"]
+            for agent_pool in agent_pools:
+                cls._api.agents.destroy(agent_pool["id"])
+            cls._logger.debug(f"Agent pools purged from test org ({cls._test_org_name}).")
 
         try:
             cls._logger.debug(f"Purging org token from test org ({cls._test_org_name})...")
@@ -187,27 +194,37 @@ class TestTFCBaseTestCase(unittest.TestCase):
         except terrasnek.exceptions.TFCHTTPUnclassified:
             cls._logger.debug(f"No org token exists for test org ({cls._test_org_name})...")
 
-
+    @classmethod
+    def _purge_module_registry(cls):
+        cls._logger.debug(f"Purging test org ({cls._test_org_name}) of modules...")
+        try:
+            registry_modules_resp = cls._api.registry_modules.list()
+            registry_modules = registry_modules_resp["modules"]
+            for registry_module in registry_modules:
+                cls._api.registry_modules.destroy(registry_module["name"])
+        except terrasnek.exceptions.TFCHTTPNotFound:
+            cls._logger.debug("No modules exist in this org, skipping.")
 
     @classmethod
     def _get_missing_entitlements(cls, endpoint_attr_name):
         endpoint = getattr(cls._api, endpoint_attr_name)
         required_entitlements = endpoint.required_entitlements()
-        current_entitlements = cls._api.orgs.entitlements(cls._test_org_name)["data"]["attributes"]
-
+        current_entitlements = cls._api.get_entitlements()
         missing_entitlements = []
-        for req_ent in required_entitlements:
-            meets_sub_requirement = False
 
-            for cur_ent_key in current_entitlements:
-                ent_enabled = current_entitlements[cur_ent_key]
-                cur_ent_key = cur_ent_key.replace("-", "_").upper()
+        if cls._api.is_terraform_cloud() and current_entitlements is not None:
+            for req_ent in required_entitlements:
+                meets_sub_requirement = False
 
-                if Entitlements[cur_ent_key] == req_ent and ent_enabled:
-                    meets_sub_requirement = True
+                for cur_ent_key in current_entitlements:
+                    ent_enabled = current_entitlements[cur_ent_key]
+                    cur_ent_key = cur_ent_key.replace("-", "_").upper()
 
-            if not meets_sub_requirement:
-                missing_entitlements.append(req_ent)
+                    if Entitlements[cur_ent_key] == req_ent and ent_enabled:
+                        meets_sub_requirement = True
+
+                if not meets_sub_requirement:
+                    missing_entitlements.append(req_ent)
 
         return missing_entitlements
 
@@ -469,7 +486,6 @@ class TestTFCBaseTestCase(unittest.TestCase):
         """
         created_run = self._api.runs.show(run_id)["data"]
         while not created_run["attributes"]["actions"]["is-confirmable"]:
-            self._logger.debug("Waiting on plan to execute...")
             created_run = self._api.runs.show(run_id)["data"]
             self._logger.debug("Waiting for created run to finish planning...")
             time.sleep(1)
