@@ -10,6 +10,9 @@ class TestTFCTeamTokens(TestTFCBaseTestCase):
     Class for testing the Terraform Cloud API Endpoint: Team Tokens.
     """
 
+    _unittest_name = "team-tok"
+    _endpoint_being_tested = "team_tokens"
+
     def setUp(self):
         self._team = self._api.teams.create(
             self._get_team_create_payload())["data"]
@@ -18,9 +21,9 @@ class TestTFCTeamTokens(TestTFCBaseTestCase):
     def tearDown(self):
         self._api.teams.destroy(self._team_id)
 
-    def test_team_token_lifecycle(self):
+    def test_team_tokens(self):
         """
-        Test the Team Tokens API endpoints: create, destroy.
+        Test the Team Tokens API endpoints.
         """
 
         # Create a test token and make sure we get an ID back
